@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Capture::Tiny;
 # ABSTRACT: Capture STDOUT and STDERR from Perl, XS or external programs
-our $VERSION = '0.15'; # VERSION
+our $VERSION = '0.16'; # VERSION
 use Carp ();
 use Exporter ();
 use IO::Handle ();
@@ -406,7 +406,7 @@ Capture::Tiny - Capture STDOUT and STDERR from Perl, XS or external programs
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -594,7 +594,7 @@ output handle after the capture is complete.  (Requires Perl 5.8)
 Capture::Tiny attempts to preserve the semantics of STDIN opened to a scalar
 reference.
 
-B<Tied handles>
+B<Tied output handles>
 
 If STDOUT or STDERR are tied prior to the call to C<<< capture >>> or C<<< tee >>>, then
 Capture::Tiny will attempt to override the tie for the duration of the
@@ -607,8 +607,28 @@ is based on L<Tie::StdHandle>, then Capture::Tiny will attempt to determine
 appropriate layers like C<<< :utf8 >>> from the underlying handle and do the right
 thing.
 
-Capture::Tiny attempts to preserve the semantics of tied STDIN, but capturing
-or teeing when STDIN is tied is currently broken on Windows.
+B<Tied input handle>
+
+Capture::Tiny attempts to preserve the semantics of tied STDIN, but this is not
+entirely stable or portable. For example:
+
+=over
+
+=item *
+
+Capturing or teeing with STDIN tied is broken on Windows
+
+=item *
+
+L<FCGI> has been reported as having a pathological tied handle implementation
+that causes fatal (and hard to diagnose) errors
+
+=back
+
+Unless having STDIN tied is crucial, it may be safest to localize STDIN when
+capturing:
+
+   my ($out, $err) = do { local *STDIN; capture { ... } };
 
 =head2 Modifying handles during a capture
 
